Class: HealthVault::WCData::Methods::CreateAuthenticatedSessionToken::AuthTokenInfo

Inherits:
ComplexType
  • Object
show all
Defined in:
lib/wc_data/generated/methods/create_authenticated_session_token/auth_token_info.rb

Instance Attribute Summary

Attributes inherited from ComplexType

#tag_name

Instance Method Summary collapse

Methods inherited from ComplexType

#add_new_to_children, #element, #method_missing, #optional_elements, #parse_element, #query_elements, #required_elements, #to_s, #valid?

Constructor Details

#initializeAuthTokenInfo

Returns a new instance of AuthTokenInfo.



48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
# File 'lib/wc_data/generated/methods/create_authenticated_session_token/auth_token_info.rb', line 48

def initialize
  super
  self.tag_name = 'authtokeninfo'

  
  @children['app-id'] = {:name => 'app-id', :class => HealthVault::WCData::Types::AppInfo, :value => nil, :min => 1, :max => 1, :order => 1, :place => :element, :choice => 0 }
    
  @children['app-id'][:value] = HealthVault::WCData::Types::AppInfo.new
    
  

  
  @children['credential'] = {:name => 'credential', :class => HealthVault::WCData::Methods::CreateAuthenticatedSessionToken::Credential, :value => nil, :min => 1, :max => 1, :order => 2, :place => :element, :choice => 0 }
    
  @children['credential'][:value] = HealthVault::WCData::Methods::CreateAuthenticatedSessionToken::Credential.new
    
  

end

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class HealthVault::WCData::ComplexType

Instance Method Details

#app_idObject

returns: a HealthVault::WCData::Types::AppInfo



27
28
29
# File 'lib/wc_data/generated/methods/create_authenticated_session_token/auth_token_info.rb', line 27

def app_id
  return @children['app-id'][:value]
end

#app_id=(value) ⇒ Object

remarks: In order for a session to be created, the user must grant access to the application to run in the context of the user. If permission has not been granted, this will result in a access denied error. value is a HealthVault::WCData::Types::AppInfo



22
23
24
# File 'lib/wc_data/generated/methods/create_authenticated_session_token/auth_token_info.rb', line 22

def app_id=(value)
  @children['app-id'][:value] = value
end

#credentialObject

returns: a HealthVault::WCData::Methods::CreateAuthenticatedSessionToken::Credential



42
43
44
# File 'lib/wc_data/generated/methods/create_authenticated_session_token/auth_token_info.rb', line 42

def credential
  return @children['credential'][:value]
end

#credential=(value) ⇒ Object

remarks: The credential serves two purposes. First, it must be verified as valid. Once verified, the credential provides the authentication context for the session. value is a HealthVault::WCData::Methods::CreateAuthenticatedSessionToken::Credential



37
38
39
# File 'lib/wc_data/generated/methods/create_authenticated_session_token/auth_token_info.rb', line 37

def credential=(value)
  @children['credential'][:value] = value
end