Class: HealthVault::WCData::Types::HMACAlgorithm

Inherits:
ComplexType
  • Object
show all
Defined in:
lib/wc_data/generated/types/hmac_algorithm.rb

Instance Attribute Summary

Attributes inherited from ComplexType

#tag_name

Instance Method Summary collapse

Methods inherited from ComplexType

#add_new_to_children, #element, #method_missing, #optional_elements, #parse_element, #query_elements, #required_elements, #to_s, #valid?

Constructor Details

#initializeHMACAlgorithm

Returns a new instance of HMACAlgorithm.



32
33
34
35
36
37
38
39
40
41
42
43
# File 'lib/wc_data/generated/types/hmac_algorithm.rb', line 32

def initialize
  super
  self.tag_name = 'hmacalgorithm'

  
  @children['hmac-alg'] = {:name => 'hmac-alg', :class => HealthVault::WCData::Types::HMACAlgorithmData, :value => nil, :min => 1, :max => 1, :order => 1, :place => :element, :choice => 0 }
    
  @children['hmac-alg'][:value] = HealthVault::WCData::Types::HMACAlgorithmData.new
    
  

end

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class HealthVault::WCData::ComplexType

Instance Method Details

#hmac_algObject

returns: a HealthVault::WCData::Types::HMACAlgorithmData



26
27
28
# File 'lib/wc_data/generated/types/hmac_algorithm.rb', line 26

def hmac_alg
  return @children['hmac-alg'][:value]
end

#hmac_alg=(value) ⇒ Object

remarks: The same algorithm must be used for all subsequent HMAC operations applied when using the same authenticated session token. value is a HealthVault::WCData::Types::HMACAlgorithmData



21
22
23
# File 'lib/wc_data/generated/types/hmac_algorithm.rb', line 21

def hmac_alg=(value)
  @children['hmac-alg'][:value] = value
end