Class: HealthVault::WCData::Types::HMACAlgorithmData
- Inherits:
-
ComplexType
- Object
- ComplexType
- HealthVault::WCData::Types::HMACAlgorithmData
- Defined in:
- lib/wc_data/generated/types/hmac_algorithm_data.rb
Instance Attribute Summary
Attributes inherited from ComplexType
Instance Method Summary collapse
-
#alg_name ⇒ Object
returns: a HealthVault::WCData::Types::Stringnz.
-
#alg_name=(value) ⇒ Object
remarks: The shared secret key is recommended to be 256 bits, or 32 bytes, of random data.
-
#data ⇒ Object
returns: a HealthVault::WCData::Types::String512.
-
#data=(value) ⇒ Object
REQUIRED value is a HealthVault::WCData::Types::String512.
-
#initialize ⇒ HMACAlgorithmData
constructor
A new instance of HMACAlgorithmData.
Methods inherited from ComplexType
#add_new_to_children, #element, #method_missing, #optional_elements, #parse_element, #query_elements, #required_elements, #to_s, #valid?
Constructor Details
#initialize ⇒ HMACAlgorithmData
Returns a new instance of HMACAlgorithmData.
45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 |
# File 'lib/wc_data/generated/types/hmac_algorithm_data.rb', line 45 def initialize super self.tag_name = 'hmacalgorithmdata' @children['data'] = {:name => 'data', :class => HealthVault::WCData::Types::String512, :value => nil, :min => 1, :max => 1, :order => 0, :place => :extension, :choice => 0 } @children['data'][:value] = HealthVault::WCData::Types::String512.new @children['algName'] = {:name => 'algName', :class => HealthVault::WCData::Types::Stringnz, :value => nil, :min => 1, :max => 1, :order => 0, :place => :attribute, :choice => 0 } @children['algName'][:value] = HealthVault::WCData::Types::Stringnz.new end |
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class HealthVault::WCData::ComplexType
Instance Method Details
#alg_name ⇒ Object
returns: a HealthVault::WCData::Types::Stringnz
39 40 41 |
# File 'lib/wc_data/generated/types/hmac_algorithm_data.rb', line 39 def alg_name return @children['algName'][:value] end |
#alg_name=(value) ⇒ Object
remarks: The shared secret key is recommended to be 256 bits, or 32 bytes, of random data. value is a HealthVault::WCData::Types::Stringnz
34 35 36 |
# File 'lib/wc_data/generated/types/hmac_algorithm_data.rb', line 34 def alg_name=(value) @children['algName'][:value] = value end |
#data ⇒ Object
returns: a HealthVault::WCData::Types::String512
24 25 26 |
# File 'lib/wc_data/generated/types/hmac_algorithm_data.rb', line 24 def data return @children['data'][:value] end |
#data=(value) ⇒ Object
REQUIRED value is a HealthVault::WCData::Types::String512
19 20 21 |
# File 'lib/wc_data/generated/types/hmac_algorithm_data.rb', line 19 def data=(value) @children['data'][:value] = value end |